/*
 * Assembly Language Debugger
 *
 * Copyright (C) 2000 Patrick Alken
 * This program comes with absolutely NO WARRANTY
 *
 * Should you choose to use and/or modify this source code, please
 * do so under the terms of the GNU General Public License under which
 * this program is distributed.
 *
 * $Id: c_quit.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
 */

#include "load.h"
#include "main.h"
#include "misc.h"

/*
c_quit()
 Terminate the program

Return: -1
*/

int
c_quit(struct aldWorkspace *ws, int ac, char **av)

{
  /*
   * Save settings to configuration file
   */
  writeRC(ws);

  return (-1);
} /* c_quit() */
